@@ -6,20 +6,21 @@ from django.contrib.auth import login, authenticate
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import User
 from django.core import signing
-from django.urls import reverse
+from django.http import JsonResponse
 from django.shortcuts import redirect, render
+from django.urls import reverse, reverse_lazy
 from django.utils.translation import gettext_lazy as _
 
 from allianceauth.eveonline.models import EveCharacter
 from esi.decorators import token_required
 from esi.models import Token
 
-from registration.backends.hmac.views import (
+from django_registration.backends.activation.views import (
     RegistrationView as BaseRegistrationView, 
     ActivationView as BaseActivationView, 
     REGISTRATION_SALT
 )
-from registration.signals import user_registered
+from django_registration.signals import user_registered
 
 from .models import CharacterOwnership
 from .forms import RegistrationForm
@@ -134,11 +135,14 @@ def sso_login(request, token):
 # Step 2
 class RegistrationView(BaseRegistrationView):
     form_class = RegistrationForm
-    success_url = 'authentication:dashboard'
+    template_name = "public/register.html"
+    email_body_template = "registration/activation_email.txt"
+    email_subject_template = "registration/activation_email_subject.txt"
+    success_url = reverse_lazy('registration_complete') 
 
     def get_success_url(self, user):
         if not getattr(settings, 'REGISTRATION_VERIFY_EMAIL', True):
-            return 'authentication:dashboard', (), {}
+            return reverse_lazy('authentication:dashboard')
         return super().get_success_url(user)
 
     def dispatch(self, request, *args, **kwargs):
@@ -176,6 +180,9 @@ class RegistrationView(BaseRegistrationView):
 
 # Step 3
 class ActivationView(BaseActivationView):
+    template_name = "registration/activate.html"
+    success_url = reverse_lazy('registration_activation_complete')    
+    
     def validate_key(self, activation_key):
         try:
             dump = signing.loads(activation_key, salt=REGISTRATION_SALT,
@@ -207,5 +214,5 @@ def activation_complete(request):
 
 
 def registration_closed(request):
-    messages.error(request, _('Registraion of new accounts it not allowed at this time.'))
+    messages.error(request, _('Registration of new accounts is not allowed at this time.'))
     return redirect('authentication:login')
