@@ -11,11 +11,7 @@ from allianceauth.eveonline.models import (
     EveCharacter, EveCorporationInfo, EveAllianceInfo
 )
 
-from ..admin import (   
-   HasLeaderFilter,
-   GroupAdmin,   
-   Group
-)
+from ..admin import HasLeaderFilter, GroupAdmin, Group
 from . import get_admin_change_view_url
 
 if 'allianceauth.eveonline.autogroups' in settings.INSTALLED_APPS:
@@ -88,33 +84,33 @@ class TestGroupAdmin(TestCase):
         
         # user 1 - corp and alliance, normal user
         cls.character_1 = EveCharacter.objects.create(
-            character_id='1001',
+            character_id=1001,
             character_name='Bruce Wayne',
-            corporation_id='2001',
+            corporation_id=2001,
             corporation_name='Wayne Technologies',
             corporation_ticker='WT',
-            alliance_id='3001',
+            alliance_id=3001,
             alliance_name='Wayne Enterprises',
             alliance_ticker='WE',
         )
         cls.character_1a = EveCharacter.objects.create(
-            character_id='1002',
+            character_id=1002,
             character_name='Batman',
-            corporation_id='2001',
+            corporation_id=2001,
             corporation_name='Wayne Technologies',
             corporation_ticker='WT',
-            alliance_id='3001',
+            alliance_id=3001,
             alliance_name='Wayne Enterprises',
             alliance_ticker='WE',
         )
         alliance = EveAllianceInfo.objects.create(
-            alliance_id='3001',
+            alliance_id=3001,
             alliance_name='Wayne Enterprises',
             alliance_ticker='WE',            
-            executor_corp_id='2001'
+            executor_corp_id=2001
         )
         EveCorporationInfo.objects.create(
-            corporation_id='2001',
+            corporation_id=2001,
             corporation_name='Wayne Technologies',
             corporation_ticker='WT',            
             member_count=42,
@@ -189,10 +185,10 @@ class TestGroupAdmin(TestCase):
             alliance=None
         )
         EveAllianceInfo.objects.create(
-            alliance_id='3101',
+            alliance_id=3101,
             alliance_name='Lex World Domination',
             alliance_ticker='LWD',
-            executor_corp_id=''
+            executor_corp_id=2101
         )
         cls.user_3 = User.objects.create_user(
             cls.character_3.character_name.replace(' ', '_'),
@@ -219,8 +215,8 @@ class TestGroupAdmin(TestCase):
         """create autogroups for corps and alliances"""
         if _has_auto_groups:
             autogroups_config = AutogroupsConfig(
-                corp_groups = True,
-                alliance_groups = True
+                corp_groups=True,
+                alliance_groups=True
             )
             autogroups_config.save()
             for state in State.objects.all():
@@ -277,7 +273,7 @@ class TestGroupAdmin(TestCase):
 
     if _has_auto_groups:
         @patch(MODULE_PATH + '._has_auto_groups', True)
-        def test_properties_6(self):
+        def test_properties_7(self):
             self._create_autogroups()
             expected = ['Auto Group']
             my_group = Group.objects\
@@ -337,8 +333,8 @@ class TestGroupAdmin(TestCase):
             changelist = my_modeladmin.get_changelist_instance(request)
             queryset = changelist.get_queryset(request)
             expected = Group.objects.exclude(
-                        managedalliancegroup__isnull=True, 
-                        managedcorpgroup__isnull=True
+                managedalliancegroup__isnull=True, 
+                managedcorpgroup__isnull=True
             )
             self.assertSetEqual(set(queryset), set(expected))
          
@@ -394,4 +390,4 @@ class TestGroupAdmin(TestCase):
         c = Client()
         c.login(username='superuser', password='secret')                
         response = c.get(get_admin_change_view_url(self.group_1))
-        self.assertEqual(response.status_code, 200)
\ No newline at end of file
+        self.assertEqual(response.status_code, 200)
