@@ -1,7 +1,10 @@
-from allianceauth.services.hooks import MenuItemHook, UrlHook
 from django.utils.translation import ugettext_lazy as _
+
 from allianceauth import hooks
-from allianceauth.hrapplications import urls
+from allianceauth.services.hooks import MenuItemHook, UrlHook
+
+from . import urls
+from .models import Application
 
 
 class ApplicationsMenu(MenuItemHook):
@@ -12,6 +15,11 @@ class ApplicationsMenu(MenuItemHook):
                               'hrapplications:index',
                               navactive=['hrapplications:'])
 
+    def render(self, request):        
+        app_count = Application.objects.pending_requests_count_for_user(request.user)
+        self.count = app_count if app_count and app_count > 0 else None
+        return MenuItemHook.render(self, request)
+    
 
 @hooks.register('menu_item_hook')
 def register_menu():
