@@ -9,4 +9,9 @@ urlpatterns = [
     url(r'^notifications/delete_all_read/$', views.delete_all_read, name='delete_all_read'),
     url(r'^notifications/$', views.notification_list, name='list'),
     url(r'^notifications/(\w+)/$', views.notification_view, name='view'),
+    url(
+        r'^user_notifications_count/(?P<user_pk>\d+)/$', 
+        views.user_notifications_count, 
+        name='user_notifications_count'
+    ),
 ]
