@@ -1,6 +1,7 @@
 import logging
 
 from django.contrib.auth.models import User, Group, Permission
+from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
 from django.db.models.signals import m2m_changed
 from django.db.models.signals import pre_delete
@@ -11,6 +12,7 @@ from .tasks import disable_user
 
 from allianceauth.authentication.models import State, UserProfile
 from allianceauth.authentication.signals import state_changed
+from allianceauth.eveonline.models import EveCharacter
 
 logger = logging.getLogger(__name__)
 
@@ -121,17 +123,12 @@ def m2m_changed_state_permissions(sender, instance, action, pk_set, *args, **kwa
             logger.debug("Permission change for state {} was not service permission, ignoring".format(instance))
 
 
-@receiver(state_changed, sender=UserProfile)
+@receiver(state_changed)
 def check_service_accounts_state_changed(sender, user, state, **kwargs):
-    logger.debug("Received state_changed from %s to state %s" % (user, state))
-    service_perms = [svc.access_perm for svc in ServicesHook.get_services()]
-    state_perms = ["{}.{}".format(perm.natural_key()[1], perm.natural_key()[0]) for perm in state.permissions.all()]
-    for perm in service_perms:
-        if perm not in state_perms:
-            for svc in ServicesHook.get_services():
-                if svc.access_perm == perm:
-                    logger.debug("User %s new state %s does not have service %s permission. Checking account." % (user, state, svc))
-                    svc.validate_user(user)
+    logger.debug("Received state_changed from %s to state %s" % (user, state))    
+    for svc in ServicesHook.get_services():
+        svc.validate_user(user)
+        svc.update_groups(user)
 
 
 @receiver(pre_delete, sender=User)
@@ -157,14 +154,62 @@ def disable_services_on_inactive(sender, instance, *args, **kwargs):
 
 
 @receiver(pre_save, sender=UserProfile)
-def disable_services_on_no_main(sender, instance, *args, **kwargs):
+def process_main_character_change(sender, instance, *args, **kwargs):    
     if not instance.pk:
-        # new model being created
+        # ignore new model being created
         return
     try:
+        logger.debug(
+            "Received pre_save from %s for process_main_character_change", instance
+        )
         old_instance = UserProfile.objects.get(pk=instance.pk)
         if old_instance.main_character and not instance.main_character:
-            logger.info("Disabling services due to loss of main character for user {0}".format(instance.user))
+            logger.info(
+                "Disabling services due to loss of main character for user %s",
+                instance.user
+            )
             disable_user(instance.user)
+        elif old_instance.main_character != instance.main_character:              
+            logger.info(
+                "Updating Names due to change of main character for user %s", 
+                instance.user
+            )
+            for svc in ServicesHook.get_services():
+                try:
+                    svc.validate_user(instance.user)
+                    svc.sync_nickname(instance.user)
+                except:
+                    logger.exception(
+                        "Exception running sync_nickname for services module %s "
+                        "on user %s", 
+                        svc, 
+                        instance
+                    )
+
     except UserProfile.DoesNotExist:
         pass
+
+
+@receiver(pre_save, sender=EveCharacter)
+def process_main_character_update(sender, instance, *args, **kwargs):
+    try:        
+        if instance.userprofile:
+            logger.debug(
+                "Received pre_save from %s for process_main_character_update", 
+                instance
+            )
+            old_instance = EveCharacter.objects.get(pk=instance.pk)
+            if not instance.character_name == old_instance.character_name or \
+               not instance.corporation_name == old_instance.corporation_name or \
+               not instance.alliance_name == old_instance.alliance_name:
+                logger.info("syncing service nickname for user {0}".format(instance.userprofile.user))
+
+                for svc in ServicesHook.get_services():
+                    try:
+                        svc.validate_user(instance.userprofile.user)
+                        svc.sync_nickname(instance.userprofile.user)
+                    except:
+                        logger.exception('Exception running sync_nickname for services module %s on user %s' % (svc, instance))
+
+    except ObjectDoesNotExist:  # not a main char ignore
+        pass
